<?php

/**
 * Ceon Tax Declaration Checkout Declaration Handling/Recording.
 *
 * @package     ceon_tax_declaration
 * @author      Conor Kerr <zen-cart@dev.ceon.net>
 * @copyright   Copyright 2008-2011 Ceon
 * @link        http://dev.ceon.net/web/zen-cart/tax-declaration
 * @license     http://www.gnu.org/copyleft/gpl.html   GNU Public License V2.0
 * @version     $Id: class.tax_declarationCheckout.php 721 2011-06-13 18:16:09Z conor $
 */

// {{{ class tax_declarationCheckout

/**
 * Records any Tax Declaration made by the customer (if any products in the shopping basket are
 * applicable).
 *
 * @package     ceon_tax_declaration
 * @author      Conor Kerr <zen-cart@dev.ceon.net>
 * @copyright   Copyright 2008-2011 Ceon
 * @link        http://dev.ceon.net/web/zen-cart/tax-declaration
 * @license     http://www.gnu.org/copyleft/gpl.html   GNU Public License V2.0
 * @version     $Id: class.tax_declarationCheckout.php 721 2011-06-13 18:16:09Z conor $
 */
class tax_declarationCheckout extends base
{
	
	function tax_declarationCheckout()
	{
		global $zco_notifier;
		
		$zco_notifier->attach($this,
			array(
				'NOTIFY_HEADER_START_CHECKOUT_SHIPPING',
				'NOTIFY_HEADER_END_CHECKOUT_SHIPPING',
				'NOTIFY_HEADER_START_CHECKOUT_PAYMENT',
				'NOTIFY_HEADER_END_CHECKOUT_PAYMENT',
				'NOTIFY_HEADER_START_CHECKOUT_CONFIRMATION',
				'NOTIFY_HEADER_START_CHECKOUT_SUCCESS'
				)
			);
	}
	
	function update(&$callingClass, $notifier, $paramsArray)
	{
		global $order, $num_products_for_tax_declaration, $tax_declaration,
			$tax_declaration_signature;
		
		if ($notifier == 'NOTIFY_HEADER_START_CHECKOUT_SHIPPING') {
			// Has a declaration been signed?
			if (isset($_POST['tax_declaration'])) {
				$tax_declaration = $_POST['tax_declaration'];
				$tax_declaration_signature = $_POST['tax_declaration_signature'];
				
				$_SESSION['tax_declaration'] = $_POST['tax_declaration'];
				$_SESSION['tax_declaration_signature'] = $_POST['tax_declaration_signature'];
			} else if (isset($_SESSION['tax_declaration'])) {
				$tax_declaration = $_SESSION['tax_declaration'];
				$tax_declaration_signature = $_SESSION['tax_declaration_signature'];
			}
		} else if ($notifier == 'NOTIFY_HEADER_END_CHECKOUT_SHIPPING') {
			// Should the declaration be requested? Only if order has applicable product(s)!
			$num_products = sizeof($order->products);
			$num_products_for_tax_declaration = 0;
			for ($i = 0; $i < $num_products; $i++) {
				if ($order->products[$i]['products_tax_declaration'] == 1) {
					$num_products_for_tax_declaration++;
				}
			}
			if (!isset($_SESSION['tax_declaration']) && $num_products_for_tax_declaration > 0) {
				$tax_declaration = '';
				$tax_declaration_signature = '';
			}
		} else if ($notifier == 'NOTIFY_HEADER_START_CHECKOUT_PAYMENT') {
			// Has a declaration been signed?
			if (isset($_POST['tax_declaration'])) {
				$tax_declaration = $_POST['tax_declaration'];
				$tax_declaration_signature = $_POST['tax_declaration_signature'];
				
				$_SESSION['tax_declaration'] = $_POST['tax_declaration'];
				$_SESSION['tax_declaration_signature'] = $_POST['tax_declaration_signature'];
			} else if (isset($_SESSION['tax_declaration'])) {
				$tax_declaration = $_SESSION['tax_declaration'];
				$tax_declaration_signature = $_SESSION['tax_declaration_signature'];
			}
		} else if ($notifier == 'NOTIFY_HEADER_END_CHECKOUT_PAYMENT') {
			// Should the declaration be requested now because the shipping stage was skipped
			if ($order->content_type == 'virtual') {
				$num_products = sizeof($order->products);
				$num_products_for_tax_declaration = 0;
				for ($i = 0; $i < $num_products; $i++) {
					if ($order->products[$i]['products_tax_declaration'] == 1) {
						$num_products_for_tax_declaration++;
					}
				}
			}
			if (!isset($_SESSION['tax_declaration']) && $num_products_for_tax_declaration > 0) {
				$tax_declaration = '';
				$tax_declaration_signature = '';
			}
		} else if ($notifier == 'NOTIFY_HEADER_START_CHECKOUT_CONFIRMATION') {
			// Has a declaration been signed?
			if (isset($_POST['tax_declaration'])) {
				$tax_declaration = $_POST['tax_declaration'];
				$tax_declaration_signature = $_POST['tax_declaration_signature'];
				
				$_SESSION['tax_declaration'] = $_POST['tax_declaration'];
				$_SESSION['tax_declaration_signature'] = $_POST['tax_declaration_signature'];
			} else if (isset($_SESSION['tax_declaration'])) {
				$tax_declaration = $_SESSION['tax_declaration'];
				$tax_declaration_signature = $_SESSION['tax_declaration_signature'];
			}
		} else if ($notifier == 'NOTIFY_HEADER_START_CHECKOUT_SUCCESS') {
			if (isset($_SESSION['tax_declaration'])) {
				unset($_SESSION['tax_declaration']);
				unset($_SESSION['tax_declaration_signature']);
			}
		}
	}
}

// }}}
 
?>